@@ -24,7 +24,7 @@ select_prediction_method <- function(fun, model, expanded_frame, ci.lvl, type, f
     fitfram <- get_predictions_lrm(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "glmmTMB") {
     # glmmTMB-objects -----
-    fitfram <- get_predictions_glmmTMB(model, expanded_frame, ci.lvl, linv, ...)
+    fitfram <- get_predictions_glmmTMB(model, expanded_frame, ci.lvl, linv, type, ...)
   } else if (fun %in% c("lmer", "nlmer", "glmer")) {
     # merMod-objects  -----
     fitfram <- get_predictions_merMod(model, expanded_frame, ci.lvl, linv, type, terms, typical, prettify, prettify.at, ...)
@@ -399,7 +399,7 @@ get_predictions_svyglmnb <- function(model, fitfram, ci.lvl, linv, ...) {
 # predictions for glmmTMB ----
 
 #' @importFrom stats family
-get_predictions_glmmTMB <- function(model, fitfram, ci.lvl, linv, ...) {
+get_predictions_glmmTMB <- function(model, fitfram, ci.lvl, linv, type, ...) {
   # does user want standard errors?
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
@@ -409,28 +409,36 @@ get_predictions_glmmTMB <- function(model, fitfram, ci.lvl, linv, ...) {
   else
     ci <- .975
 
+
+  # check whether predictions should be conditioned
+  # on random effects (grouping level) or not.
+  if (type == "fe")
+    ref <- NA
+  else
+    ref <- NULL
+
+
   prdat <- stats::predict(
     model,
     newdata = fitfram,
-    zitype = "response",
-    type = "response",
+    type = "link",
     se.fit = se,
+    # not implemented in glmmTMB <= 0.2.1
+    # re.form = ref,
     ...
   )
 
+
   # did user request standard errors? if yes, compute CI
   if (se) {
-    fitfram$predicted <- prdat$fit
-
-    # see http://www.biorxiv.org/content/biorxiv/suppl/2017/05/01/132753.DC1/132753-2.pdf
-    # page 7
+    fitfram$predicted <- linv(prdat$fit)
 
     # calculate CI
-    fitfram$conf.low <- prdat$fit - stats::qnorm(ci) * prdat$se.fit
-    fitfram$conf.high <- prdat$fit + stats::qnorm(ci) * prdat$se.fit
+    fitfram$conf.low <- linv(prdat$fit - stats::qnorm(ci) * prdat$se.fit)
+    fitfram$conf.high <- linv(prdat$fit + stats::qnorm(ci) * prdat$se.fit)
   } else {
     # copy predictions
-    fitfram$predicted <- as.vector(prdat)
+    fitfram$predicted <- linv(as.vector(prdat))
 
     # no CI
     fitfram$conf.low <- NA
@@ -616,6 +624,12 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, faminfo, ppd, ter
 
     for (i in resp.vars) {
       pos <- tidyselect::ends_with(i, vars = tmp$grp)
+
+      if (sjmisc::is_empty(pos)) {
+        i <- gsub(pattern = "[\\_\\.]", replacement = "", x = i)
+        pos <- tidyselect::ends_with(i, vars = tmp$grp)
+      }
+
       fitfram$response.level[pos] <- i
     }
 
@@ -997,7 +1011,8 @@ get_se_from_vcov <- function(model, fitfram, typical, terms, fun = NULL, type =
     fac.typical = FALSE,
     type = type,
     prettify = prettify,
-    prettify.at = prettify.at
+    prettify.at = prettify.at,
+    pretty.message = FALSE
   )
 
   # add response
