@@ -30,6 +30,10 @@ ggplot(mydf, aes(x, predicted, colour = group)) +
   geom_line() + 
   facet_wrap(~facet)
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+mydf <- ggpredict(fit)
+mydf
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 mydf <- ggaverage(fit, terms = c("c12hour", "c172code"))
 ggplot(mydf, aes(x, predicted, colour = group)) + geom_line()
@@ -46,9 +50,13 @@ mpg_model <- lm(mpg ~ log(hp), data = mtcars)
 # x-values and predictions based on the log(hp)-values
 ggpredict(mpg_model, "hp")
 
-# x-values and predictions based hp-values from 50 to 150
+# x-values and predictions based on hp-values from 50 to 150
 ggpredict(mpg_model, "hp [50:150]")
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+# x-values and predictions based on exponentiated hp-values
+ggpredict(mpg_model, "hp [exp]")
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(sjmisc)
 data(efc)
